@@ -2354,6 +2354,28 @@ static long ColourOfProperty(PropSetFile *props, const char *key, ColourDesired
 	return colourDefault.AsLong();
 }
 
+void AnEditor::SetGtkStyle(Window &win, int style) {
+	GtkWidgetPath *path;
+	GtkStyleContext *context;
+	GdkRGBA fore;
+	GdkRGBA back;
+	const PangoFontDescription *desc;
+
+	/* Get theme style information for view widget */
+	path = gtk_widget_path_new ();
+	gtk_widget_path_append_type (path, GTK_TYPE_WIDGET);
+	context = gtk_style_context_new ();
+	gtk_style_context_set_path (context, path);
+	gtk_widget_path_free (path);
+	gtk_style_context_add_class (context, GTK_STYLE_CLASS_VIEW);
+	gtk_style_context_get_color (context, GTK_STATE_FLAG_NORMAL, &fore);
+	gtk_style_context_get_background_color (context, GTK_STATE_FLAG_NORMAL, &back);
+	g_object_unref (context);
+
+	Platform::SendScintilla(win.GetID(), SCI_STYLESETFORE, style, (gint)(fore.red * 255) | ((gint)(fore.green * 255) << 8) | ((gint)(fore.blue *255) << 16));
+	Platform::SendScintilla(win.GetID(), SCI_STYLESETBACK, style, (gint)(back.red * 255) | ((gint)(back.green * 255) << 8) | ((gint)(back.blue *255) << 16));
+}
+
 void AnEditor::SetOneStyle(Window &win, int style, const char *s) {
 	char *val = StringDup(s);
 	char *opt = val;
@@ -2469,6 +2491,8 @@ SString AnEditor::FindLanguageProperty(const char *pattern, const char *defaultV
 
 void AnEditor::ReadProperties(const char *fileForExt, char **typedef_hl) {
 	//DWORD dwStart = timeGetTime();
+	int blink_time = 500;
+
 	if (fileForExt)
 		strcpy (fileName, fileForExt);
 	else
@@ -2580,8 +2604,20 @@ void AnEditor::ReadProperties(const char *fileForExt, char **typedef_hl) {
 
 	SString caretPeriod = props->Get("caret.period");
 	if (caretPeriod.length()) {
-		SendEditor(SCI_SETCARETPERIOD, caretPeriod.value());
+		blink_time = caretPeriod.value();
 	}
+	else {
+		GtkSettings *settings = gtk_settings_get_default();
+		gboolean blink;
+
+        g_object_get(G_OBJECT (settings),
+                     "gtk-cursor-blink", &blink,
+                     "gtk-cursor-blink-time", &blink_time,
+                     NULL);
+		blink_time /= 2;
+		if (!blink) blink_time = 0;
+	}
+	SendEditor(SCI_SETCARETPERIOD, blink_time);
 
 	int caretSlop = props->GetInt("caret.policy.xslop", 1) ? CARET_SLOP : 0;
 	int caretZone = props->GetInt("caret.policy.width", 50);
@@ -2751,6 +2787,8 @@ void AnEditor::ReadProperties(const char *fileForExt, char **typedef_hl) {
 
 	SendEditor(SCI_STYLERESETDEFAULT, 0, 0);
 
+	SetGtkStyle(wEditor, STYLE_DEFAULT);
+
 	sprintf(key, "style.%s.%0d", "*", STYLE_DEFAULT);
 	sval = props->GetNewExpand(key, "");
 	SetOneStyle(wEditor, STYLE_DEFAULT, sval.c_str());
@@ -2769,8 +2807,6 @@ void AnEditor::ReadProperties(const char *fileForExt, char **typedef_hl) {
 	}
 
 	/* Gtk handles it correctly */
-	SendEditor(SCI_SETUSEPALETTE, 0);
-
 	SendEditor(SCI_SETPRINTMAGNIFICATION, props->GetInt("print.magnification"));
 	SendEditor(SCI_SETPRINTCOLOURMODE, props->GetInt("print.colour.mode"));
 
